@@ -119,7 +119,7 @@ class Conf():
 
         #password enforcement
         cls.passwordpreviousdifferent = int(settings.get("ppss_auth.password_previuos_diff","3"))
-        cls.passwordrelist = Conf.conf2list( settings.get("ppss_auth.password_relist",["[A-Z]+","[a-z]+","[0-9]+","[!,\.\?\\/;:_\-+*@]+"]) )
+        cls.passwordrelist = Conf.conf2list( settings.get("ppss_auth.password_relist",["[A-Z]+","[a-z]+","[0-9]+","[!,\.\?\\/;:_\-+*@\£\$\%\&\(\)\"\'=\^àèìòùé\#§°ç{}]+"]) )
         cls.passwordwrongmessage = 'La nuova password deve essere differente dalle precedenti 3 e avere almeno una maiuscola, una minuscola, un numero e un carattere fra "!,.?\\/;:_-+*".'
         cls.passwordexpiredmessage = 'Password expired. Please change it.'
         cls.passwordexpire =  int(settings.get("ppss_auth.password_expire",0)  )
