@@ -91,6 +91,8 @@ class AuthController():
         return user
 
     def __init__(self,request):
+        request.response.headers["X-Frame-Options"] = "DENY"
+        request.response.headers["Content-Security-Policy"] = "frame-ancestors 'none';"
         self.request = request
         self.user = None
         activemenu = ""
